# Backends

GPU acceleration and backend configuration for TF-MInDi.

```{eval-rst}
.. currentmodule:: tfmindi

.. autosummary::
    :toctree: ../generated

    get_backend
    set_backend
    is_gpu_available
```
